==> ultracopier_1.6.1.3.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/de/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="303"/>
        <location filename="../../interface.cpp" line="320"/>
        <source>%1 is deprecated, Use %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="306"/>
        <location filename="../../interface.cpp" line="323"/>
        <source>This will be the last version for Mac, but you can compile from source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="325"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Kaufe die Ultimate Version um die Entwicklung zu finanzieren</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="410"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Datei %1/%2, Größe:%3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="644"/>
        <source>Copy list</source>
        <translation>Zu kopierende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="646"/>
        <source>Move list</source>
        <translation>Zu verschiebende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1067"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1068"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1069"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1071"/>
        <source>File Name, 0KB</source>
        <translation>Dateiname, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1265"/>
        <location filename="../../interface.cpp" line="1277"/>
        <location filename="../../interface.cpp" line="1289"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1364"/>
        <location filename="../../interface.cpp" line="1368"/>
        <location filename="../../interface.cpp" line="1370"/>
        <source>%1 %2% of %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="284"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="285"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="286"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="482"/>
        <location filename="../../ThemesFactory.cpp" line="497"/>
        <location filename="../../ThemesFactory.cpp" line="512"/>
        <source>Select a color</source>
        <translation>Wählen Sie eine Farbe</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="35"/>
        <source>From:</source>
        <translation>Von:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="65"/>
        <source>To:</source>
        <translation>Nach:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="226"/>
        <source>&amp;More</source>
        <translation>&amp;Mehr</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="246"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="260"/>
        <source>&amp;Skip</source>
        <translation>Über&amp;springen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="271"/>
        <source>&amp;Cancel</source>
        <translation>Abbrechen (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="329"/>
        <source>Transfer list</source>
        <translation>Dateiliste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="485"/>
        <source>Delete the selected items</source>
        <translation>Ausgewählte Einträge löschen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="540"/>
        <source>Export the transfer list</source>
        <translation>Dateiliste exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="566"/>
        <source>Import the transfer list</source>
        <translation>Dateiliste importieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="621"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="628"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="741"/>
        <source>Interface</source>
        <translation>Darstellungsoptionen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="352"/>
        <source>Move the selected items to the top</source>
        <translation>Ausgewählte Einträge an den Listenanfang verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="118"/>
        <source>Close on transfer completion</source>
        <translation>Am Ende des Transfers schließen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="286"/>
        <source>Limit copy speed to:</source>
        <translation>Begrenze Kopiergeschwindigkeit auf:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="378"/>
        <source>Move up the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach oben verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="404"/>
        <source>Move down the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach unten verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="430"/>
        <source>Move the selected items to the bottom</source>
        <translation>Ausgewählte Einträge an das Listenende verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="456"/>
        <source>Add file/folder</source>
        <translation>Datei/Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="511"/>
        <source>Search</source>
        <translation>In Dateiliste suchen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="663"/>
        <location filename="../../interface.ui" line="732"/>
        <source>Error</source>
        <translation>Fehlerprotokoll</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="683"/>
        <source>Export the errors into transfer list</source>
        <translation>Fehlgeschlagene Dateien exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="722"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="727"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="778"/>
        <source>Add file</source>
        <translation>Datei hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="787"/>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Move file(s)</source>
        <translation>Datei(en) verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Move folder</source>
        <translation>Ordner verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Copy file(s)</source>
        <translation>Datei(en) kopieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Copy folder</source>
        <translation>Verzeichnis kopieren</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="267"/>
        <source>Show dual progression</source>
        <translation>Zweifachen Fortschritt anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Geschwindigkeitsbegrenzungsschieberegler anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Benutzung</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Standardmäßig &quot;Mehr&quot; Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Beim Schließen ins Systray minimieren</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>Am Ende des Vorgangs</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Begrenze Übertragungsgeschwindigkeit auf</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="306"/>
        <source>Click to edit the color</source>
        <translation>Zum Bearbeiten der Farbe klicken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Informations</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="257"/>
        <source>Speed with progress bar</source>
        <translation>Geschwindigkeit als Fortschrittsbalken anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="287"/>
        <source>Progression color</source>
        <translation>Farbe des Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Show progression in the title</source>
        <translation>Fortschritt im Fenstertitel zeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Fenster immer im Vordergrund</translation>
    </message>
</context>
</TS>

==> ultracopier_2.2.4.4.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/de/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="327"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Kaufe die Ultimate Version um die Entwicklung zu finanzieren</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="412"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>Datei %1/%2, Größe:%3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="646"/>
        <source>Copy list</source>
        <translation>Zu kopierende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="648"/>
        <source>Move list</source>
        <translation>Zu verschiebende Dateien</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1076"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1077"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1078"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1080"/>
        <source>File Name, 0KB</source>
        <translation>Dateiname, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1274"/>
        <location filename="../../interface.cpp" line="1286"/>
        <location filename="../../interface.cpp" line="1298"/>
        <source>Select a color</source>
        <translation>Farbe auswählen</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1373"/>
        <location filename="../../interface.cpp" line="1377"/>
        <location filename="../../interface.cpp" line="1379"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% von %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="284"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Nicht schließen, wenn Fehler aufgetreten sind</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="285"/>
        <source>Never close</source>
        <translation>Niemals schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="286"/>
        <source>Always close</source>
        <translation>Immer schließen</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="482"/>
        <location filename="../../ThemesFactory.cpp" line="497"/>
        <location filename="../../ThemesFactory.cpp" line="512"/>
        <source>Select a color</source>
        <translation>Wählen Sie eine Farbe</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="35"/>
        <source>From:</source>
        <translation>Von:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="65"/>
        <source>To:</source>
        <translation>Nach:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="226"/>
        <source>&amp;More</source>
        <translation>&amp;Mehr</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="246"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="260"/>
        <source>&amp;Skip</source>
        <translation>Über&amp;springen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="271"/>
        <source>&amp;Cancel</source>
        <translation>Abbrechen (&amp;C)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="329"/>
        <source>Transfer list</source>
        <translation>Dateiliste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="485"/>
        <source>Delete the selected items</source>
        <translation>Ausgewählte Einträge löschen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="540"/>
        <source>Export the transfer list</source>
        <translation>Dateiliste exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="566"/>
        <source>Import the transfer list</source>
        <translation>Dateiliste importieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="621"/>
        <source>Previous</source>
        <translation>Vorherige</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="628"/>
        <source>Next</source>
        <translation>Nächste</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="741"/>
        <source>Interface</source>
        <translation>Darstellungsoptionen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="352"/>
        <source>Move the selected items to the top</source>
        <translation>Ausgewählte Einträge an den Listenanfang verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="118"/>
        <source>Close on transfer completion</source>
        <translation>Am Ende des Transfers schließen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="286"/>
        <source>Limit copy speed to:</source>
        <translation>Begrenze Kopiergeschwindigkeit auf:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="378"/>
        <source>Move up the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach oben verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="404"/>
        <source>Move down the selected items</source>
        <translation>Ausgewählte Einträge einen Platz nach unten verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="430"/>
        <source>Move the selected items to the bottom</source>
        <translation>Ausgewählte Einträge an das Listenende verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="456"/>
        <source>Add file/folder</source>
        <translation>Datei/Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="511"/>
        <source>Search</source>
        <translation>In Dateiliste suchen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="663"/>
        <location filename="../../interface.ui" line="732"/>
        <source>Error</source>
        <translation>Fehlerprotokoll</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="683"/>
        <source>Export the errors into transfer list</source>
        <translation>Fehlgeschlagene Dateien exportieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="722"/>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="727"/>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="778"/>
        <source>Add file</source>
        <translation>Datei hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="787"/>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Move file(s)</source>
        <translation>Datei(en) verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Move folder</source>
        <translation>Ordner verschieben</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Copy file(s)</source>
        <translation>Datei(en) kopieren</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Copy folder</source>
        <translation>Verzeichnis kopieren</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="267"/>
        <source>Show dual progression</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Geschwindigkeitsbegrenzungsschieberegler anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Benutzung</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Standardmäßig &quot;Mehr&quot; Informationen anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Beim Schließen ins Systray minimieren</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>Am Ende des Vorgangs</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Begrenze Übertragungsgeschwindigkeit auf</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>Minimiert starten</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="306"/>
        <source>Click to edit the color</source>
        <translation>Zum Bearbeiten der Farbe klicken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>Speichere Fensterposition</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Informations</source>
        <translation>Informationen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="257"/>
        <source>Speed with progress bar</source>
        <translation>Geschwindigkeit als Fortschrittsbalken anzeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="287"/>
        <source>Progression color</source>
        <translation>Farbe des Fortschrittsbalken</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Show progression in the title</source>
        <translation>Fortschritt im Fenstertitel zeigen</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Fenster immer im Vordergrund halten</translation>
    </message>
</context>
</TS>
